Struct aws_sdk_workspacesweb::Client
source · [−]pub struct Client { /* private fields */ }Expand description
Client for Amazon WorkSpaces Web
Client for invoking operations on Amazon WorkSpaces Web. Each operation on Amazon WorkSpaces Web is a method on this
this struct. .send() MUST be invoked on the generated operations to dispatch the request to the service.
Examples
Constructing a client and invoking an operation
// create a shared configuration. This can be used & shared between multiple service clients.
let shared_config = aws_config::load_from_env().await;
let client = aws_sdk_workspacesweb::Client::new(&shared_config);
// invoke an operation
/* let rsp = client
.<operation_name>().
.<param>("some value")
.send().await; */Constructing a client with custom configuration
use aws_config::RetryConfig;
let shared_config = aws_config::load_from_env().await;
let config = aws_sdk_workspacesweb::config::Builder::from(&shared_config)
.retry_config(RetryConfig::disabled())
.build();
let client = aws_sdk_workspacesweb::Client::from_conf(config);Implementations
sourceimpl Client
impl Client
sourcepub fn with_config(
client: Client<DynConnector, DynMiddleware<DynConnector>>,
conf: Config
) -> Self
pub fn with_config(
client: Client<DynConnector, DynMiddleware<DynConnector>>,
conf: Config
) -> Self
Creates a client with the given service configuration.
sourceimpl Client
impl Client
sourcepub fn associate_browser_settings(&self) -> AssociateBrowserSettings
pub fn associate_browser_settings(&self) -> AssociateBrowserSettings
Constructs a fluent builder for the AssociateBrowserSettings operation.
- The fluent builder is configurable:
portal_arn(impl Into<String>)/set_portal_arn(Option<String>):The ARN of the web portal.
browser_settings_arn(impl Into<String>)/set_browser_settings_arn(Option<String>):The ARN of the browser settings.
- On success, responds with
AssociateBrowserSettingsOutputwith field(s):portal_arn(Option<String>):The ARN of the web portal.
browser_settings_arn(Option<String>):The ARN of the browser settings.
- On failure, responds with
SdkError<AssociateBrowserSettingsError>
sourcepub fn associate_network_settings(&self) -> AssociateNetworkSettings
pub fn associate_network_settings(&self) -> AssociateNetworkSettings
Constructs a fluent builder for the AssociateNetworkSettings operation.
- The fluent builder is configurable:
portal_arn(impl Into<String>)/set_portal_arn(Option<String>):The ARN of the web portal.
network_settings_arn(impl Into<String>)/set_network_settings_arn(Option<String>):The ARN of the network settings.
- On success, responds with
AssociateNetworkSettingsOutputwith field(s):portal_arn(Option<String>):The ARN of the web portal.
network_settings_arn(Option<String>):The ARN of the network settings.
- On failure, responds with
SdkError<AssociateNetworkSettingsError>
sourcepub fn associate_trust_store(&self) -> AssociateTrustStore
pub fn associate_trust_store(&self) -> AssociateTrustStore
Constructs a fluent builder for the AssociateTrustStore operation.
- The fluent builder is configurable:
portal_arn(impl Into<String>)/set_portal_arn(Option<String>):The ARN of the web portal.
trust_store_arn(impl Into<String>)/set_trust_store_arn(Option<String>):The ARN of the trust store.
- On success, responds with
AssociateTrustStoreOutputwith field(s):portal_arn(Option<String>):The ARN of the web portal.
trust_store_arn(Option<String>):The ARN of the trust store.
- On failure, responds with
SdkError<AssociateTrustStoreError>
sourcepub fn associate_user_settings(&self) -> AssociateUserSettings
pub fn associate_user_settings(&self) -> AssociateUserSettings
Constructs a fluent builder for the AssociateUserSettings operation.
- The fluent builder is configurable:
portal_arn(impl Into<String>)/set_portal_arn(Option<String>):The ARN of the web portal.
user_settings_arn(impl Into<String>)/set_user_settings_arn(Option<String>):The ARN of the user settings.
- On success, responds with
AssociateUserSettingsOutputwith field(s):portal_arn(Option<String>):The ARN of the web portal.
user_settings_arn(Option<String>):The ARN of the user settings.
- On failure, responds with
SdkError<AssociateUserSettingsError>
sourcepub fn create_browser_settings(&self) -> CreateBrowserSettings
pub fn create_browser_settings(&self) -> CreateBrowserSettings
Constructs a fluent builder for the CreateBrowserSettings operation.
- The fluent builder is configurable:
tags(Vec<Tag>)/set_tags(Option<Vec<Tag>>):The tags to add to the browser settings resource. A tag is a key-value pair.
customer_managed_key(impl Into<String>)/set_customer_managed_key(Option<String>):The custom managed key of the browser settings.
additional_encryption_context(HashMap<String, String>)/set_additional_encryption_context(Option<HashMap<String, String>>):Additional encryption context of the browser settings.
browser_policy(impl Into<String>)/set_browser_policy(Option<String>):A JSON string containing Chrome Enterprise policies that will be applied to all streaming sessions.
client_token(impl Into<String>)/set_client_token(Option<String>):A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Idempotency ensures that an API request completes only once. With an idempotent request, if the original request completes successfully, subsequent retries with the same client token returns the result from the original successful request.
If you do not specify a client token, one is automatically generated by the AWS SDK.
- On success, responds with
CreateBrowserSettingsOutputwith field(s):browser_settings_arn(Option<String>):The ARN of the browser settings.
- On failure, responds with
SdkError<CreateBrowserSettingsError>
sourcepub fn create_identity_provider(&self) -> CreateIdentityProvider
pub fn create_identity_provider(&self) -> CreateIdentityProvider
Constructs a fluent builder for the CreateIdentityProvider operation.
- The fluent builder is configurable:
portal_arn(impl Into<String>)/set_portal_arn(Option<String>):The ARN of the web portal.
identity_provider_name(impl Into<String>)/set_identity_provider_name(Option<String>):The identity provider name.
identity_provider_type(IdentityProviderType)/set_identity_provider_type(Option<IdentityProviderType>):The identity provider type.
identity_provider_details(HashMap<String, String>)/set_identity_provider_details(Option<HashMap<String, String>>):The identity provider details. The following list describes the provider detail keys for each identity provider type.
-
For Google and Login with Amazon:
-
client_id -
client_secret -
authorize_scopes
-
-
For Facebook:
-
client_id -
client_secret -
authorize_scopes -
api_version
-
-
For Sign in with Apple:
-
client_id -
team_id -
key_id -
private_key -
authorize_scopes
-
-
For OIDC providers:
-
client_id -
client_secret -
attributes_request_method -
oidc_issuer -
authorize_scopes -
authorize_urlif not available from discovery URL specified byoidc_issuerkey -
token_urlif not available from discovery URL specified byoidc_issuerkey -
attributes_urlif not available from discovery URL specified byoidc_issuerkey -
jwks_uriif not available from discovery URL specified byoidc_issuerkey
-
-
For SAML providers:
-
MetadataFileORMetadataURL -
IDPSignoutoptional
-
-
client_token(impl Into<String>)/set_client_token(Option<String>):A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Idempotency ensures that an API request completes only once. With an idempotent request, if the original request completes successfully, subsequent retries with the same client token returns the result from the original successful request.
If you do not specify a client token, one is automatically generated by the AWS SDK.
- On success, responds with
CreateIdentityProviderOutputwith field(s):identity_provider_arn(Option<String>):The ARN of the identity provider.
- On failure, responds with
SdkError<CreateIdentityProviderError>
sourcepub fn create_network_settings(&self) -> CreateNetworkSettings
pub fn create_network_settings(&self) -> CreateNetworkSettings
Constructs a fluent builder for the CreateNetworkSettings operation.
- The fluent builder is configurable:
vpc_id(impl Into<String>)/set_vpc_id(Option<String>):The VPC that streaming instances will connect to.
subnet_ids(Vec<String>)/set_subnet_ids(Option<Vec<String>>):The subnets in which network interfaces are created to connect streaming instances to your VPC. At least two of these subnets must be in different availability zones.
security_group_ids(Vec<String>)/set_security_group_ids(Option<Vec<String>>):One or more security groups used to control access from streaming instances to your VPC.
tags(Vec<Tag>)/set_tags(Option<Vec<Tag>>):The tags to add to the network settings resource. A tag is a key-value pair.
client_token(impl Into<String>)/set_client_token(Option<String>):A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Idempotency ensures that an API request completes only once. With an idempotent request, if the original request completes successfully, subsequent retries with the same client token returns the result from the original successful request.
If you do not specify a client token, one is automatically generated by the AWS SDK.
- On success, responds with
CreateNetworkSettingsOutputwith field(s):network_settings_arn(Option<String>):The ARN of the network settings.
- On failure, responds with
SdkError<CreateNetworkSettingsError>
sourcepub fn create_portal(&self) -> CreatePortal
pub fn create_portal(&self) -> CreatePortal
Constructs a fluent builder for the CreatePortal operation.
- The fluent builder is configurable:
display_name(impl Into<String>)/set_display_name(Option<String>):The name of the web portal. This is not visible to users who log into the web portal.
tags(Vec<Tag>)/set_tags(Option<Vec<Tag>>):The tags to add to the web portal. A tag is a key-value pair.
customer_managed_key(impl Into<String>)/set_customer_managed_key(Option<String>):The customer managed key of the web portal.
additional_encryption_context(HashMap<String, String>)/set_additional_encryption_context(Option<HashMap<String, String>>):The additional encryption context of the portal.
client_token(impl Into<String>)/set_client_token(Option<String>):A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Idempotency ensures that an API request completes only once. With an idempotent request, if the original request completes successfully, subsequent retries with the same client token returns the result from the original successful request.
If you do not specify a client token, one is automatically generated by the AWS SDK.
- On success, responds with
CreatePortalOutputwith field(s):portal_arn(Option<String>):The ARN of the web portal.
portal_endpoint(Option<String>):The endpoint URL of the web portal that users access in order to start streaming sessions.
- On failure, responds with
SdkError<CreatePortalError>
sourcepub fn create_trust_store(&self) -> CreateTrustStore
pub fn create_trust_store(&self) -> CreateTrustStore
Constructs a fluent builder for the CreateTrustStore operation.
- The fluent builder is configurable:
certificate_list(Vec<Blob>)/set_certificate_list(Option<Vec<Blob>>):A list of CA certificates to be added to the trust store.
tags(Vec<Tag>)/set_tags(Option<Vec<Tag>>):The tags to add to the trust store. A tag is a key-value pair.
client_token(impl Into<String>)/set_client_token(Option<String>):A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Idempotency ensures that an API request completes only once. With an idempotent request, if the original request completes successfully, subsequent retries with the same client token returns the result from the original successful request.
If you do not specify a client token, one is automatically generated by the AWS SDK.
- On success, responds with
CreateTrustStoreOutputwith field(s):trust_store_arn(Option<String>):The ARN of the trust store.
- On failure, responds with
SdkError<CreateTrustStoreError>
sourcepub fn create_user_settings(&self) -> CreateUserSettings
pub fn create_user_settings(&self) -> CreateUserSettings
Constructs a fluent builder for the CreateUserSettings operation.
- The fluent builder is configurable:
copy_allowed(EnabledType)/set_copy_allowed(Option<EnabledType>):Specifies whether the user can copy text from the streaming session to the local device.
paste_allowed(EnabledType)/set_paste_allowed(Option<EnabledType>):Specifies whether the user can paste text from the local device to the streaming session.
download_allowed(EnabledType)/set_download_allowed(Option<EnabledType>):Specifies whether the user can download files from the streaming session to the local device.
upload_allowed(EnabledType)/set_upload_allowed(Option<EnabledType>):Specifies whether the user can upload files from the local device to the streaming session.
print_allowed(EnabledType)/set_print_allowed(Option<EnabledType>):Specifies whether the user can print to the local device.
tags(Vec<Tag>)/set_tags(Option<Vec<Tag>>):The tags to add to the user settings resource. A tag is a key-value pair.
client_token(impl Into<String>)/set_client_token(Option<String>):A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Idempotency ensures that an API request completes only once. With an idempotent request, if the original request completes successfully, subsequent retries with the same client token returns the result from the original successful request.
If you do not specify a client token, one is automatically generated by the AWS SDK.
- On success, responds with
CreateUserSettingsOutputwith field(s):user_settings_arn(Option<String>):The ARN of the user settings.
- On failure, responds with
SdkError<CreateUserSettingsError>
sourcepub fn delete_browser_settings(&self) -> DeleteBrowserSettings
pub fn delete_browser_settings(&self) -> DeleteBrowserSettings
Constructs a fluent builder for the DeleteBrowserSettings operation.
- The fluent builder is configurable:
browser_settings_arn(impl Into<String>)/set_browser_settings_arn(Option<String>):The ARN of the browser settings.
- On success, responds with
DeleteBrowserSettingsOutput - On failure, responds with
SdkError<DeleteBrowserSettingsError>
sourcepub fn delete_identity_provider(&self) -> DeleteIdentityProvider
pub fn delete_identity_provider(&self) -> DeleteIdentityProvider
Constructs a fluent builder for the DeleteIdentityProvider operation.
- The fluent builder is configurable:
identity_provider_arn(impl Into<String>)/set_identity_provider_arn(Option<String>):The ARN of the identity provider.
- On success, responds with
DeleteIdentityProviderOutput - On failure, responds with
SdkError<DeleteIdentityProviderError>
sourcepub fn delete_network_settings(&self) -> DeleteNetworkSettings
pub fn delete_network_settings(&self) -> DeleteNetworkSettings
Constructs a fluent builder for the DeleteNetworkSettings operation.
- The fluent builder is configurable:
network_settings_arn(impl Into<String>)/set_network_settings_arn(Option<String>):The ARN of the network settings.
- On success, responds with
DeleteNetworkSettingsOutput - On failure, responds with
SdkError<DeleteNetworkSettingsError>
sourcepub fn delete_portal(&self) -> DeletePortal
pub fn delete_portal(&self) -> DeletePortal
Constructs a fluent builder for the DeletePortal operation.
- The fluent builder is configurable:
portal_arn(impl Into<String>)/set_portal_arn(Option<String>):The ARN of the web portal.
- On success, responds with
DeletePortalOutput - On failure, responds with
SdkError<DeletePortalError>
sourcepub fn delete_trust_store(&self) -> DeleteTrustStore
pub fn delete_trust_store(&self) -> DeleteTrustStore
Constructs a fluent builder for the DeleteTrustStore operation.
- The fluent builder is configurable:
trust_store_arn(impl Into<String>)/set_trust_store_arn(Option<String>):The ARN of the trust store.
- On success, responds with
DeleteTrustStoreOutput - On failure, responds with
SdkError<DeleteTrustStoreError>
sourcepub fn delete_user_settings(&self) -> DeleteUserSettings
pub fn delete_user_settings(&self) -> DeleteUserSettings
Constructs a fluent builder for the DeleteUserSettings operation.
- The fluent builder is configurable:
user_settings_arn(impl Into<String>)/set_user_settings_arn(Option<String>):The ARN of the user settings.
- On success, responds with
DeleteUserSettingsOutput - On failure, responds with
SdkError<DeleteUserSettingsError>
sourcepub fn disassociate_browser_settings(&self) -> DisassociateBrowserSettings
pub fn disassociate_browser_settings(&self) -> DisassociateBrowserSettings
Constructs a fluent builder for the DisassociateBrowserSettings operation.
- The fluent builder is configurable:
portal_arn(impl Into<String>)/set_portal_arn(Option<String>):The ARN of the web portal.
- On success, responds with
DisassociateBrowserSettingsOutput - On failure, responds with
SdkError<DisassociateBrowserSettingsError>
sourcepub fn disassociate_network_settings(&self) -> DisassociateNetworkSettings
pub fn disassociate_network_settings(&self) -> DisassociateNetworkSettings
Constructs a fluent builder for the DisassociateNetworkSettings operation.
- The fluent builder is configurable:
portal_arn(impl Into<String>)/set_portal_arn(Option<String>):The ARN of the web portal.
- On success, responds with
DisassociateNetworkSettingsOutput - On failure, responds with
SdkError<DisassociateNetworkSettingsError>
sourcepub fn disassociate_trust_store(&self) -> DisassociateTrustStore
pub fn disassociate_trust_store(&self) -> DisassociateTrustStore
Constructs a fluent builder for the DisassociateTrustStore operation.
- The fluent builder is configurable:
portal_arn(impl Into<String>)/set_portal_arn(Option<String>):The ARN of the web portal.
- On success, responds with
DisassociateTrustStoreOutput - On failure, responds with
SdkError<DisassociateTrustStoreError>
sourcepub fn disassociate_user_settings(&self) -> DisassociateUserSettings
pub fn disassociate_user_settings(&self) -> DisassociateUserSettings
Constructs a fluent builder for the DisassociateUserSettings operation.
- The fluent builder is configurable:
portal_arn(impl Into<String>)/set_portal_arn(Option<String>):The ARN of the web portal.
- On success, responds with
DisassociateUserSettingsOutput - On failure, responds with
SdkError<DisassociateUserSettingsError>
sourcepub fn get_browser_settings(&self) -> GetBrowserSettings
pub fn get_browser_settings(&self) -> GetBrowserSettings
Constructs a fluent builder for the GetBrowserSettings operation.
- The fluent builder is configurable:
browser_settings_arn(impl Into<String>)/set_browser_settings_arn(Option<String>):The ARN of the browser settings.
- On success, responds with
GetBrowserSettingsOutputwith field(s):browser_settings(Option<BrowserSettings>):The browser settings.
- On failure, responds with
SdkError<GetBrowserSettingsError>
sourcepub fn get_identity_provider(&self) -> GetIdentityProvider
pub fn get_identity_provider(&self) -> GetIdentityProvider
Constructs a fluent builder for the GetIdentityProvider operation.
- The fluent builder is configurable:
identity_provider_arn(impl Into<String>)/set_identity_provider_arn(Option<String>):The ARN of the identity provider.
- On success, responds with
GetIdentityProviderOutputwith field(s):identity_provider(Option<IdentityProvider>):The identity provider.
- On failure, responds with
SdkError<GetIdentityProviderError>
sourcepub fn get_network_settings(&self) -> GetNetworkSettings
pub fn get_network_settings(&self) -> GetNetworkSettings
Constructs a fluent builder for the GetNetworkSettings operation.
- The fluent builder is configurable:
network_settings_arn(impl Into<String>)/set_network_settings_arn(Option<String>):The ARN of the network settings.
- On success, responds with
GetNetworkSettingsOutputwith field(s):network_settings(Option<NetworkSettings>):The network settings.
- On failure, responds with
SdkError<GetNetworkSettingsError>
sourcepub fn get_portal(&self) -> GetPortal
pub fn get_portal(&self) -> GetPortal
Constructs a fluent builder for the GetPortal operation.
- The fluent builder is configurable:
portal_arn(impl Into<String>)/set_portal_arn(Option<String>):The ARN of the web portal.
- On success, responds with
GetPortalOutputwith field(s):portal(Option<Portal>):The web portal.
- On failure, responds with
SdkError<GetPortalError>
sourcepub fn get_portal_service_provider_metadata(
&self
) -> GetPortalServiceProviderMetadata
pub fn get_portal_service_provider_metadata(
&self
) -> GetPortalServiceProviderMetadata
Constructs a fluent builder for the GetPortalServiceProviderMetadata operation.
- The fluent builder is configurable:
portal_arn(impl Into<String>)/set_portal_arn(Option<String>):The ARN of the web portal.
- On success, responds with
GetPortalServiceProviderMetadataOutputwith field(s):portal_arn(Option<String>):The ARN of the web portal.
service_provider_saml_metadata(Option<String>):The service provider SAML metadata.
- On failure, responds with
SdkError<GetPortalServiceProviderMetadataError>
sourcepub fn get_trust_store(&self) -> GetTrustStore
pub fn get_trust_store(&self) -> GetTrustStore
Constructs a fluent builder for the GetTrustStore operation.
- The fluent builder is configurable:
trust_store_arn(impl Into<String>)/set_trust_store_arn(Option<String>):The ARN of the trust store.
- On success, responds with
GetTrustStoreOutputwith field(s):trust_store(Option<TrustStore>):The trust store.
- On failure, responds with
SdkError<GetTrustStoreError>
sourcepub fn get_trust_store_certificate(&self) -> GetTrustStoreCertificate
pub fn get_trust_store_certificate(&self) -> GetTrustStoreCertificate
Constructs a fluent builder for the GetTrustStoreCertificate operation.
- The fluent builder is configurable:
trust_store_arn(impl Into<String>)/set_trust_store_arn(Option<String>):The ARN of the trust store certificate.
thumbprint(impl Into<String>)/set_thumbprint(Option<String>):The thumbprint of the trust store certificate.
- On success, responds with
GetTrustStoreCertificateOutputwith field(s):trust_store_arn(Option<String>):The ARN of the trust store certificate.
certificate(Option<Certificate>):The certificate of the trust store certificate.
- On failure, responds with
SdkError<GetTrustStoreCertificateError>
sourcepub fn get_user_settings(&self) -> GetUserSettings
pub fn get_user_settings(&self) -> GetUserSettings
Constructs a fluent builder for the GetUserSettings operation.
- The fluent builder is configurable:
user_settings_arn(impl Into<String>)/set_user_settings_arn(Option<String>):The ARN of the user settings.
- On success, responds with
GetUserSettingsOutputwith field(s):user_settings(Option<UserSettings>):The user settings.
- On failure, responds with
SdkError<GetUserSettingsError>
sourcepub fn list_browser_settings(&self) -> ListBrowserSettings
pub fn list_browser_settings(&self) -> ListBrowserSettings
Constructs a fluent builder for the ListBrowserSettings operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
next_token(impl Into<String>)/set_next_token(Option<String>):The pagination token used to retrieve the next page of results for this operation.
max_results(i32)/set_max_results(Option<i32>):The maximum number of results to be included in the next page.
- On success, responds with
ListBrowserSettingsOutputwith field(s):browser_settings(Option<Vec<BrowserSettingsSummary>>):The browser settings.
next_token(Option<String>):The pagination token used to retrieve the next page of results for this operation.
- On failure, responds with
SdkError<ListBrowserSettingsError>
sourcepub fn list_identity_providers(&self) -> ListIdentityProviders
pub fn list_identity_providers(&self) -> ListIdentityProviders
Constructs a fluent builder for the ListIdentityProviders operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
next_token(impl Into<String>)/set_next_token(Option<String>):The pagination token used to retrieve the next page of results for this operation.
max_results(i32)/set_max_results(Option<i32>):The maximum number of results to be included in the next page.
portal_arn(impl Into<String>)/set_portal_arn(Option<String>):The ARN of the web portal.
- On success, responds with
ListIdentityProvidersOutputwith field(s):next_token(Option<String>):The pagination token used to retrieve the next page of results for this operation.
identity_providers(Option<Vec<IdentityProviderSummary>>):The identity providers.
- On failure, responds with
SdkError<ListIdentityProvidersError>
sourcepub fn list_network_settings(&self) -> ListNetworkSettings
pub fn list_network_settings(&self) -> ListNetworkSettings
Constructs a fluent builder for the ListNetworkSettings operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
next_token(impl Into<String>)/set_next_token(Option<String>):The pagination token used to retrieve the next page of results for this operation.
max_results(i32)/set_max_results(Option<i32>):The maximum number of results to be included in the next page.
- On success, responds with
ListNetworkSettingsOutputwith field(s):network_settings(Option<Vec<NetworkSettingsSummary>>):The network settings.
next_token(Option<String>):The pagination token used to retrieve the next page of results for this operation.
- On failure, responds with
SdkError<ListNetworkSettingsError>
sourcepub fn list_portals(&self) -> ListPortals
pub fn list_portals(&self) -> ListPortals
Constructs a fluent builder for the ListPortals operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
next_token(impl Into<String>)/set_next_token(Option<String>):The pagination token used to retrieve the next page of results for this operation.
max_results(i32)/set_max_results(Option<i32>):The maximum number of results to be included in the next page.
- On success, responds with
ListPortalsOutputwith field(s):portals(Option<Vec<PortalSummary>>):The portals in the list.
next_token(Option<String>):The pagination token used to retrieve the next page of results for this operation.
- On failure, responds with
SdkError<ListPortalsError>
Constructs a fluent builder for the ListTagsForResource operation.
- The fluent builder is configurable:
resource_arn(impl Into<String>)/set_resource_arn(Option<String>):The ARN of the resource.
- On success, responds with
ListTagsForResourceOutputwith field(s):tags(Option<Vec<Tag>>):The tags of the resource.
- On failure, responds with
SdkError<ListTagsForResourceError>
sourcepub fn list_trust_store_certificates(&self) -> ListTrustStoreCertificates
pub fn list_trust_store_certificates(&self) -> ListTrustStoreCertificates
Constructs a fluent builder for the ListTrustStoreCertificates operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
trust_store_arn(impl Into<String>)/set_trust_store_arn(Option<String>):The ARN of the trust store
next_token(impl Into<String>)/set_next_token(Option<String>):The pagination token used to retrieve the next page of results for this operation.
max_results(i32)/set_max_results(Option<i32>):The maximum number of results to be included in the next page.
- On success, responds with
ListTrustStoreCertificatesOutputwith field(s):certificate_list(Option<Vec<CertificateSummary>>):The certificate list.
trust_store_arn(Option<String>):The ARN of the trust store.
next_token(Option<String>):The pagination token used to retrieve the next page of results for this operation.>
- On failure, responds with
SdkError<ListTrustStoreCertificatesError>
sourcepub fn list_trust_stores(&self) -> ListTrustStores
pub fn list_trust_stores(&self) -> ListTrustStores
Constructs a fluent builder for the ListTrustStores operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
next_token(impl Into<String>)/set_next_token(Option<String>):The pagination token used to retrieve the next page of results for this operation.
max_results(i32)/set_max_results(Option<i32>):The maximum number of results to be included in the next page.
- On success, responds with
ListTrustStoresOutputwith field(s):trust_stores(Option<Vec<TrustStoreSummary>>):The trust stores.
next_token(Option<String>):The pagination token used to retrieve the next page of results for this operation.
- On failure, responds with
SdkError<ListTrustStoresError>
sourcepub fn list_user_settings(&self) -> ListUserSettings
pub fn list_user_settings(&self) -> ListUserSettings
Constructs a fluent builder for the ListUserSettings operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
next_token(impl Into<String>)/set_next_token(Option<String>):The pagination token used to retrieve the next page of results for this operation.
max_results(i32)/set_max_results(Option<i32>):The maximum number of results to be included in the next page.
- On success, responds with
ListUserSettingsOutputwith field(s):user_settings(Option<Vec<UserSettingsSummary>>):The user settings.
next_token(Option<String>):The pagination token used to retrieve the next page of results for this operation.
- On failure, responds with
SdkError<ListUserSettingsError>
sourcepub fn tag_resource(&self) -> TagResource
pub fn tag_resource(&self) -> TagResource
Constructs a fluent builder for the TagResource operation.
- The fluent builder is configurable:
resource_arn(impl Into<String>)/set_resource_arn(Option<String>):The ARN of the resource.
tags(Vec<Tag>)/set_tags(Option<Vec<Tag>>):The tags of the resource.
client_token(impl Into<String>)/set_client_token(Option<String>):A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Idempotency ensures that an API request completes only once. With an idempotent request, if the original request completes successfully, subsequent retries with the same client token returns the result from the original successful request.
If you do not specify a client token, one is automatically generated by the AWS SDK.
- On success, responds with
TagResourceOutput - On failure, responds with
SdkError<TagResourceError>
sourcepub fn untag_resource(&self) -> UntagResource
pub fn untag_resource(&self) -> UntagResource
Constructs a fluent builder for the UntagResource operation.
- The fluent builder is configurable:
resource_arn(impl Into<String>)/set_resource_arn(Option<String>):The ARN of the resource.
tag_keys(Vec<String>)/set_tag_keys(Option<Vec<String>>):The list of tag keys to remove from the resource.
- On success, responds with
UntagResourceOutput - On failure, responds with
SdkError<UntagResourceError>
sourcepub fn update_browser_settings(&self) -> UpdateBrowserSettings
pub fn update_browser_settings(&self) -> UpdateBrowserSettings
Constructs a fluent builder for the UpdateBrowserSettings operation.
- The fluent builder is configurable:
browser_settings_arn(impl Into<String>)/set_browser_settings_arn(Option<String>):The ARN of the browser settings.
browser_policy(impl Into<String>)/set_browser_policy(Option<String>):A JSON string containing Chrome Enterprise policies that will be applied to all streaming sessions.
client_token(impl Into<String>)/set_client_token(Option<String>):A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Idempotency ensures that an API request completes only once. With an idempotent request, if the original request completes successfully, subsequent retries with the same client token return the result from the original successful request.
If you do not specify a client token, one is automatically generated by the AWS SDK.
- On success, responds with
UpdateBrowserSettingsOutputwith field(s):browser_settings(Option<BrowserSettings>):The browser settings.
- On failure, responds with
SdkError<UpdateBrowserSettingsError>
sourcepub fn update_identity_provider(&self) -> UpdateIdentityProvider
pub fn update_identity_provider(&self) -> UpdateIdentityProvider
Constructs a fluent builder for the UpdateIdentityProvider operation.
- The fluent builder is configurable:
identity_provider_arn(impl Into<String>)/set_identity_provider_arn(Option<String>):The ARN of the identity provider.
identity_provider_name(impl Into<String>)/set_identity_provider_name(Option<String>):The name of the identity provider.
identity_provider_type(IdentityProviderType)/set_identity_provider_type(Option<IdentityProviderType>):The type of the identity provider.
identity_provider_details(HashMap<String, String>)/set_identity_provider_details(Option<HashMap<String, String>>):The details of the identity provider.
client_token(impl Into<String>)/set_client_token(Option<String>):A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Idempotency ensures that an API request completes only once. With an idempotent request, if the original request completes successfully, subsequent retries with the same client token return the result from the original successful request.
If you do not specify a client token, one is automatically generated by the AWS SDK.
- On success, responds with
UpdateIdentityProviderOutputwith field(s):identity_provider(Option<IdentityProvider>):The identity provider.
- On failure, responds with
SdkError<UpdateIdentityProviderError>
sourcepub fn update_network_settings(&self) -> UpdateNetworkSettings
pub fn update_network_settings(&self) -> UpdateNetworkSettings
Constructs a fluent builder for the UpdateNetworkSettings operation.
- The fluent builder is configurable:
network_settings_arn(impl Into<String>)/set_network_settings_arn(Option<String>):The ARN of the network settings.
vpc_id(impl Into<String>)/set_vpc_id(Option<String>):The VPC that streaming instances will connect to.
subnet_ids(Vec<String>)/set_subnet_ids(Option<Vec<String>>):The subnets in which network interfaces are created to connect streaming instances to your VPC. At least two of these subnets must be in different availability zones.
security_group_ids(Vec<String>)/set_security_group_ids(Option<Vec<String>>):One or more security groups used to control access from streaming instances to your VPC.
client_token(impl Into<String>)/set_client_token(Option<String>):A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Idempotency ensures that an API request completes only once. With an idempotent request, if the original request completes successfully, subsequent retries with the same client token return the result from the original successful request.
If you do not specify a client token, one is automatically generated by the AWS SDK.
- On success, responds with
UpdateNetworkSettingsOutputwith field(s):network_settings(Option<NetworkSettings>):The network settings.
- On failure, responds with
SdkError<UpdateNetworkSettingsError>
sourcepub fn update_portal(&self) -> UpdatePortal
pub fn update_portal(&self) -> UpdatePortal
Constructs a fluent builder for the UpdatePortal operation.
- The fluent builder is configurable:
portal_arn(impl Into<String>)/set_portal_arn(Option<String>):The ARN of the web portal.
display_name(impl Into<String>)/set_display_name(Option<String>):The name of the web portal. This is not visible to users who log into the web portal.
- On success, responds with
UpdatePortalOutputwith field(s):portal(Option<Portal>):The web portal.
- On failure, responds with
SdkError<UpdatePortalError>
sourcepub fn update_trust_store(&self) -> UpdateTrustStore
pub fn update_trust_store(&self) -> UpdateTrustStore
Constructs a fluent builder for the UpdateTrustStore operation.
- The fluent builder is configurable:
trust_store_arn(impl Into<String>)/set_trust_store_arn(Option<String>):The ARN of the trust store.
certificates_to_add(Vec<Blob>)/set_certificates_to_add(Option<Vec<Blob>>):A list of CA certificates to add to the trust store.
certificates_to_delete(Vec<String>)/set_certificates_to_delete(Option<Vec<String>>):A list of CA certificates to delete from a trust store.
client_token(impl Into<String>)/set_client_token(Option<String>):A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Idempotency ensures that an API request completes only once. With an idempotent request, if the original request completes successfully, subsequent retries with the same client token return the result from the original successful request.
If you do not specify a client token, one is automatically generated by the AWS SDK.
- On success, responds with
UpdateTrustStoreOutputwith field(s):trust_store_arn(Option<String>):The ARN of the trust store.
- On failure, responds with
SdkError<UpdateTrustStoreError>
sourcepub fn update_user_settings(&self) -> UpdateUserSettings
pub fn update_user_settings(&self) -> UpdateUserSettings
Constructs a fluent builder for the UpdateUserSettings operation.
- The fluent builder is configurable:
user_settings_arn(impl Into<String>)/set_user_settings_arn(Option<String>):The ARN of the user settings.
copy_allowed(EnabledType)/set_copy_allowed(Option<EnabledType>):Specifies whether the user can copy text from the streaming session to the local device.
paste_allowed(EnabledType)/set_paste_allowed(Option<EnabledType>):Specifies whether the user can paste text from the local device to the streaming session.
download_allowed(EnabledType)/set_download_allowed(Option<EnabledType>):Specifies whether the user can download files from the streaming session to the local device.
upload_allowed(EnabledType)/set_upload_allowed(Option<EnabledType>):Specifies whether the user can upload files from the local device to the streaming session.
print_allowed(EnabledType)/set_print_allowed(Option<EnabledType>):Specifies whether the user can print to the local device.
client_token(impl Into<String>)/set_client_token(Option<String>):A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Idempotency ensures that an API request completes only once. With an idempotent request, if the original request completes successfully, subsequent retries with the same client token return the result from the original successful request.
If you do not specify a client token, one is automatically generated by the AWS SDK.
- On success, responds with
UpdateUserSettingsOutputwith field(s):user_settings(Option<UserSettings>):The user settings.
- On failure, responds with
SdkError<UpdateUserSettingsError>
sourceimpl Client
impl Client
sourcepub fn from_conf_conn<C, E>(conf: Config, conn: C) -> Self where
C: SmithyConnector<Error = E> + Send + 'static,
E: Into<ConnectorError>,
pub fn from_conf_conn<C, E>(conf: Config, conn: C) -> Self where
C: SmithyConnector<Error = E> + Send + 'static,
E: Into<ConnectorError>,
Creates a client with the given service config and connector override.